netapp_ontap.models.iscsi_connection API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.iscsi_connection`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class IscsiConnectionSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the IscsiConnection object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `authentication_type GET`

    The iSCSI authentication type used to establish the connection.

    Valid choices:

    - chap
    - none
  `cid GET`

    The identifier of the connection within the session.

  `initiator_address GET POST PATCH`

    The initiator_address field of the iscsi_connection.

  `interface GET POST PATCH`

    The interface field of the iscsi_connection.

  `links GET`

    The links field of the iscsi_connection.